==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/acq/nls/fr-ca/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Ainsi, des fiches bibliographiques, des codes topographiques et des dossiers seront cr\u00e9\u00e9s dans le syst\u00e8me int\u00e9gr\u00e9 de gestion de biblioth\u00e8que pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Cela aura pour effet d\u2019annuler la r\u00e9ception de tous les exemplaires pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Cela aura pour effet d\u2019annuler la r\u00e9ception de tous les exemplaires pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":XUL_RECORD_DETAIL_PAGE": "D\u00e9tails sur le dossier",
    ":DELETE_LI_COPIES_CONFIRM": "Cela aura pour effet de supprimer les derniers ${0} exemplaires dans le tableau. Voulez-vous continuer?",
    ":NO_PO_RESULTS": "Aucun r\u00e9sultat",
    ":PO_HEADING_ERROR": "Probl\u00e8me non pr\u00e9vu lors de la mise au point d\u2019un bon de commande virtuel combin\u00e9",
    ":CONFIRM_SPLIT_PO": "\u00cates-vous certain de vouloir diviser ce bon de commande en \naucun bon de commande pour chaque article constituant?",
    ":DFA_NOT_ALL": "Could not record all of your applications of distribution formulas.",
    ":APPLY": "Appliquer",
    ":RESET_FORMULAE": "R\u00e9initialiser les formules",
    ":OUT_OF_COPIES": "Vous avez appliqu\u00e9 les formules de distribution \u00e0 tous les exemplaires.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "Il n\u2019est pas possible de chercher une valeur d\u2019attribut et un fichier t\u00e9l\u00e9charg\u00e9 des termes en m\u00eame temps.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "S\u00e9lectionner un fichier ainsi que des crit\u00e8res de recherche",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Ce fichier est trop volumineux pour cette op\u00e9ration.",
    ":SELECT_AN_LI_ATTRIBUTE": "Vous devez s\u00e9lectionner un attribut pour l\u2019article.",
    ":NO_RESULTS": "Aucun r\u00e9sultat",
    ":EXPORT_SAVE_DIALOG_TITLE": "Sauvegarder les valeurs de champ dans un fichier",
    ":EXPORT_SHORT_LIST": "Les articles s\u00e9lectionn\u00e9s ne poss\u00e8dent pas tous l\u2019attribut '${0}'.\nAppuyer sur OK pour sauvegarder les valeurs qui n\u2019ont pas pu \u00eatre rep\u00e9r\u00e9es.",
    ":EXPORT_EMPTY_LIST": "Aucun r\u00e9sultat pour l\u2019attribut '${0}'",
    ":UNRECEIVE_LI": "\u00cates-vous certain de vouloir indiquer cet article comme NON re\u00e7u?",
    ":UNRECEIVE_LID": "\u00cates-vous certain de vouloir signaler cet exemplaire comme NON re\u00e7u?",
    ":CONFIRM_LI_ALERT": "Une alerte a \u00e9t\u00e9 activ\u00e9e pour l\u2019article intitul\u00e9 ,\\n\\\"${0}\\\":\\n\\n${1}\\n${2}\\n${3}\\n. Appuyer sur OK si vous d\u00e9sirez accuser r\u00e9ception de cette alerte.",
    ":ALERT_UNSELECTED": "Vous devez choisir un code d\u2019alerte.",
    ":DFA_TIP": "<strong>R\u00e9alis\u00e9(e) par</strong> : ${0}<br /><strong>Date :</strong>: ${1}",
    ":ITS_YOU": "Vous",
    ":JUST_NOW": "\u00c0 l\u2019instant",
    ":EXPLAIN_DFA_MGMT": "Supprimer le dossier de ce type de formule de distribution?",
    ":VENDOR_PUBLIC": "FOURNISSEUR : PUBLIC",
    ":PO_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler ce bon de commande?",
    ":LI_CANCEL_CONFIRM": "\u00cates-vous certain de vouloir indiquer cet article comme NON re\u00e7u?",
    ":LID_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler cet exemplaire?",
    ":UR_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler cette demande d\u2019un usager?",
    ":UR_FILTER_USER": "Enter barcode for user (or leave blank to unset the filter):",
    ":UR_FILTER_LINEITEM": "Enter id for lineitem (or leave blank to unset the filter):",
    ":CANCEL_REASON": "Annuler le motif",
    ":CANCEL": "Annuler",
    ":YES": "Oui",
    ":NO": "Non",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "Selon les dossiers, le fournisseur s\u00e9lectionn\u00e9 n\u2019exige pas n\u00e9cessairement \nun paiement anticip\u00e9. Exiger quand m\u00eame un paiement anticip\u00e9 pour ce BdC\u00a0?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "Selon les dossiers, le fournisseur s\u00e9lectionn\u00e9 exige un paiement anticip\u00e9.\nProc\u00e9der quand m\u00eame sans exiger un paiement anticip\u00e9 pour ce bon de commande?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Ce bon de commande n\u00e9cessite un paiement anticip\u00e9. \u00cates-vous certain d\u2019\u00eatre pr\u00eat \u00e0 l\u2019activer?",
    ":LI_FORMAT_ERROR": "Une erreur inattendue s\u2019est produite lors de la r\u00e9cup\u00e9ration des renseignements structur\u00e9s sur l\u2019article.",
    ":FUND_NOT_YET_LOADED": "Les fonds ne sont pas encore charg\u00e9s. Essayer d\u2019acc\u00e9der plus tard \u00e0 cet \u00e9cran.",
    ":CONFIRM_DELETE_MAPPING": "\u00cates-vous certain de vouloir supprimer cette \u00e9tiquette de ce fonds?",
    ":COULD_NOT_CREATE_MAPPING": "Une erreur s\u2019est produite lors de l\u2019\u00e9tiquetage du fonds.",
    ":COULD_NOT_DELETE_MAPPING": "Une erreur s\u2019est produite lors du retrait de l\u2019\u00e9tiquette du fonds.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "R\u00e9partition des fonds &amp; sommaire du refinancement pour l\u2019exercice ${0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "${1} funds propagated for fiscal year ${0} for the selected locations",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b> les fonds non d\u00e9pens\u00e9s sont prolong\u00e9s \u00e0 l\u2019exercice ${0} pour les emplacements s\u00e9lectionn\u00e9s.",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "Transfert impossible. La provenance et la destination des fonds sont les m\u00eames.",
    ":FUND_XFER_CONFIRM": "\u00cates-vous certain d\u2019\u00eatre pr\u00eat \u00e0 proc\u00e9der \u00e0 ce transfert?",
    ":PO_ACTIVATED_ON": "Activ\u00e9(e) ${0}",
    ":PO_CHECKING": "[Un instant...]",
    ":PO_COULD_ACTIVATE": "Oui",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "Oui. Le fonds ${0} (${1}) serait consign\u00e9 au-del\u00e0 de son niveau d\u2019avertissement.",
    ":PO_STOP_BLOCKS_ACTIVATION": "Non. Les fonds ${0} (${1}) seraient consign\u00e9s au-del\u00e0 de leur niveau d\u2019arr\u00eat.",
    ":PO_ALREADY_ACTIVATED": "Activated",
    ":PO_FUND_WARNING_CONFIRM": "\u00cates-vous certain? Avez-vous vu le message d\u2019avertissement concernant la suraffectation d\u2019un fonds?",
    ":CONFIRM_FUNDS_AT_STOP": "Le solde d\u2019un ou de plusieurs des fonds s\u00e9lectionn\u00e9s est inf\u00e9rieur \u00e0 son niveau d\u2019arr\u00eat. \\nVous pourriez ne pas pouvoir activer les bons de commande qui comprennent ces exemplaires.\\nVoulez-vous continuer?",
    ":CONFIRM_FUNDS_AT_WARNING": "Le solde d\u2019un ou de plusieurs des fonds s\u00e9lectionn\u00e9s est inf\u00e9rieur \u00e0 son niveau d\u2019avertissement.\nVoulez-vous continuer?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Estimation du prix : $${3}. <br/> Identification de l\u2019article : ${4} <br/> Bon de commande : ${5} <br/> Date de la commande : ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "Supprimer ces frais $${0} '${1}' de la facture?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "Supprimer les frais $${0} pour l\u2019article '${1}, ${2} [${3}] de la facture?",
    ":LINEITEM_SUMMARY": "<div class='acq-lineitem-summary'><a target='_top' href='${19}'>${0}</a>, by ${1} (${2})</div>\n<div class='acq-lineitem-summary-extra'>\n${3} Ordered, ${4} Received, ${7} Invoiced, ${8} Claimed, ${9} Cancelled, ${23} Delayed</div>\n<div class='acq-lineitem-summary-extra'>Estimated $${6}, Encumbered $${16}, Paid $${17}</div>\n<div class='acq-lineitem-summary-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}'  target='_top' href='/eg2/en-US/staff/acq/po/${12}#${10}'>&#x2318; ${13} ${18}</a>\n<a style='padding-right: 10px;' class='hidden${21}' target='_top' href='/eg2/en-US/staff/acq/picklist/${14}#${10}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "Frais calcul\u00e9s au prorata?\n\nToute modification subs\u00e9quente \u00e0 la facture qui affecterait les montants calcul\u00e9s au prorata devrait \u00eatre r\u00e9alis\u00e9e manuellement.",
    ":INVOICE_EXTRA_COPIES": "Vous tentez de facturer <b>${0}</b> un nombre d\u2019exemplaires plus \u00e9lev\u00e9 que celui command\u00e9 au d\u00e9part. <br/><br/>Pour ajouter ces articles \u00e0 la commande initiale, s\u00e9lectionner un fonds et choisir \u00ab Ajouter un nouvel article \u00bb ci-dessous. <br/>Apr\u00e8s avoir sauvegard\u00e9 la facture, vous pouvez terminer la modification et l\u2019importation de nouveaux exemplaires \u00e0 la page des d\u00e9tails de l\u2019article.",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sans nom",
    ":NO_FIND_INVOICE": "Impossible de trouver cette facture.",
    ":LI_BATCH_UPDATE": "Line item batch update",
    ":NO_LI_TO_UPDATE": "You have not selected any line items to update.",
    ":NO_LI_TO_CLAIM": "You have not selected any line items to claim.",
    ":NO_LID_TO_CLAIM": "You have not selected any line item details to claim.",
    ":CHANGE_CLAIM_POLICY": "Modifier la politique relative aux r\u00e9clamations",
    ":CANCELED": "Annul\u00e9",
    ":RECVD": "Re\u00e7u(e)",
    ":NOT_RECVD": "Pas re\u00e7u",
    ":PRINT": "Imprim\u00e9",
    ":INVOICES": "Factures",
    ":NUM_CLAIMS_EXISTING": "R\u00e9clamations (${0} existantes)",
    ":LOAD_TERMS_FIRST": "Vous ne pouvez pas r\u00e9cup\u00e9rer les dossiers tant que vous n\u2019avez pas charg\u00e9 un fichier en format CSV comportant \ndes identifications bibliographiques dans la premi\u00e8re colonne.",
    ":SELECT_SEARCH_FIELD": "S\u00e9lectionnez le champ de recherche",
    ":LIBRARY_INITIATED": "Librairie initi\u00e9e",
    ":DEL_LI_FROM_PO": "That item has already been ordered!  Deleting it now will not revoke or modify any order that has been placed with a vendor.  Deleting the item may put the system's idea of your purchase order in a state that is inconsistent with reality.  Are you sure you mean to do this?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "The selected PO has already been activated",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "The selected lineitem is not in a state that can be added to a purchase order",
    ":INVOICE_NUMBER": "Invoice #${0}",
    ":COPIES_TO_RECEIVE": "Number of copies to receive: ",
    ":CREATE_PO_INVALID": "A purchase order must have an ordering agency and a provider.",
    ":INVOICE_COPY_COUNT_INFO": "Copies received on this invoice: ${0} out of ${1}.",
    ":INVOICE_IDENT_COLLIDE": "There is already an invoice in the system with the given combination of 'Vendor Invoice ID' and 'Provider,' which is not allowed.",
    ":NEW_INVOICE": "New Invoice",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "LI",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "PO",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "You have not selected any (suitable) line items.",
    ":DUPE_PO_NAME_MSG": "This name is already in use by another PO",
    ":DUPE_PO_NAME_LINK": "View PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalize this blanket PO?\nThis will disencumber all blanket charges and mark the PO as received",
    ":LI_EXISTING_COPIES": "There are ${0} existing copies for this bibliographic record at this location",
    ":LI_CREATING_ASSETS": "Creating bib, call number, and copy records...",
    ":PO_ACTIVATING": "Activating purchase order...",
    ":ACTIVATE_LI_PROCESSED": "Lineitems Processed: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Records Processed: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Bib Records Merged/Imported: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copies Processed: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "Debits Encumbered: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "Real Copies Processed: ${0}"
}

==> Evergreen-ILS-3.16.2.tar.gz: Evergreen-ILS-3.16.2/Open-ILS/web/js/dojo/openils/acq/nls/fr-ca/acq.js <==
{
    ":CREATE_PO_ASSETS_CONFIRM": "Ainsi, des fiches bibliographiques, des codes topographiques et des dossiers seront cr\u00e9\u00e9s dans le syst\u00e8me int\u00e9gr\u00e9 de gestion de biblioth\u00e8que pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":ROLLBACK_PO_RECEIVE_CONFIRM": "Cela aura pour effet d\u2019annuler la r\u00e9ception de tous les exemplaires pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":ROLLBACK_LI_RECEIVE_CONFIRM": "Cela aura pour effet d\u2019annuler la r\u00e9ception de tous les exemplaires pour ce bon de commande.\n\nVoulez-vous continuer?",
    ":XUL_RECORD_DETAIL_PAGE": "D\u00e9tails sur le dossier",
    ":DELETE_LI_COPIES_CONFIRM": "Cela aura pour effet de supprimer les derniers ${0} exemplaires dans le tableau. Voulez-vous continuer?",
    ":NO_PO_RESULTS": "Aucun r\u00e9sultat",
    ":PO_HEADING_ERROR": "Probl\u00e8me non pr\u00e9vu lors de la mise au point d\u2019un bon de commande virtuel combin\u00e9",
    ":CONFIRM_SPLIT_PO": "\u00cates-vous certain de vouloir diviser ce bon de commande en \naucun bon de commande pour chaque article constituant?",
    ":DFA_NOT_ALL": "Impossible d\u2019enregistrer toutes vos applications des formules de distribution.",
    ":APPLY": "Appliquer",
    ":RESET_FORMULAE": "R\u00e9initialiser les formules",
    ":OUT_OF_COPIES": "Vous avez appliqu\u00e9 les formules de distribution \u00e0 tous les exemplaires.",
    ":ONE_LI_ATTR_SEARCH_AT_A_TIME": "Il n\u2019est pas possible de chercher une valeur d\u2019attribut et un fichier t\u00e9l\u00e9charg\u00e9 des termes en m\u00eame temps.",
    ":LI_ATTR_SEARCH_CHOOSE_FILE": "S\u00e9lectionner un fichier ainsi que des crit\u00e8res de recherche",
    ":LI_ATTR_SEARCH_TOO_LARGE": "Ce fichier est trop volumineux pour cette op\u00e9ration.",
    ":SELECT_AN_LI_ATTRIBUTE": "Vous devez s\u00e9lectionner un attribut pour l\u2019article.",
    ":NO_RESULTS": "Aucun r\u00e9sultat",
    ":EXPORT_SAVE_DIALOG_TITLE": "Sauvegarder les valeurs de champ dans un fichier",
    ":EXPORT_SHORT_LIST": "Les articles s\u00e9lectionn\u00e9s ne poss\u00e8dent pas tous l\u2019attribut '${0}'.\nAppuyer sur OK pour sauvegarder les valeurs qui n\u2019ont pas pu \u00eatre rep\u00e9r\u00e9es.",
    ":EXPORT_EMPTY_LIST": "Aucun r\u00e9sultat pour l\u2019attribut '${0}'",
    ":UNRECEIVE_LI": "\u00cates-vous certain de vouloir indiquer cet article comme NON re\u00e7u?",
    ":UNRECEIVE_LID": "\u00cates-vous certain de vouloir signaler cet exemplaire comme NON re\u00e7u?",
    ":CONFIRM_LI_ALERT": "Une alerte a \u00e9t\u00e9 activ\u00e9e pour l\u2019article intitul\u00e9 ,\\n\\\"${0}\\\":\\n\\n${1}\\n${2}\\n${3}\\n. Appuyer sur OK si vous d\u00e9sirez accuser r\u00e9ception de cette alerte.",
    ":ALERT_UNSELECTED": "Vous devez choisir un code d\u2019alerte.",
    ":DFA_TIP": "<strong>R\u00e9alis\u00e9(e) par</strong> : ${0}<br /><strong>Date :</strong>: ${1}",
    ":ITS_YOU": "Vous",
    ":JUST_NOW": "\u00c0 l\u2019instant",
    ":EXPLAIN_DFA_MGMT": "Supprimer le dossier de ce type de formule de distribution?",
    ":VENDOR_PUBLIC": "FOURNISSEUR : PUBLIC",
    ":PO_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler ce bon de commande?",
    ":LI_CANCEL_CONFIRM": "\u00cates-vous certain de vouloir indiquer cet article comme NON re\u00e7u?",
    ":LID_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler cet exemplaire?",
    ":UR_CANCEL_CONFIRM": "\u00cates-vous CERTAIN de vouloir annuler cette demande d\u2019un usager?",
    ":UR_FILTER_USER": "Enter barcode for user (or leave blank to unset the filter):",
    ":UR_FILTER_LINEITEM": "Enter id for lineitem (or leave blank to unset the filter):",
    ":CANCEL_REASON": "Annuler le motif",
    ":CANCEL": "Annuler",
    ":YES": "Oui",
    ":NO": "Non",
    ":VENDOR_SAYS_PREPAY_NOT_NEEDED": "Selon les dossiers, le fournisseur s\u00e9lectionn\u00e9 n\u2019exige pas n\u00e9cessairement \nun paiement anticip\u00e9. Exiger quand m\u00eame un paiement anticip\u00e9 pour ce BdC\u00a0?",
    ":VENDOR_SAYS_PREPAY_NEEDED": "Selon les dossiers, le fournisseur s\u00e9lectionn\u00e9 exige un paiement anticip\u00e9.\nProc\u00e9der quand m\u00eame sans exiger un paiement anticip\u00e9 pour ce bon de commande?",
    ":PREPAYMENT_REQUIRED_REMINDER": "Ce bon de commande n\u00e9cessite un paiement anticip\u00e9. \u00cates-vous certain d\u2019\u00eatre pr\u00eat \u00e0 l\u2019activer?",
    ":LI_FORMAT_ERROR": "Une erreur inattendue s\u2019est produite lors de la r\u00e9cup\u00e9ration des renseignements structur\u00e9s sur l\u2019article.",
    ":FUND_NOT_YET_LOADED": "Les fonds ne sont pas encore charg\u00e9s. Essayer d\u2019acc\u00e9der plus tard \u00e0 cet \u00e9cran.",
    ":CONFIRM_DELETE_MAPPING": "\u00cates-vous certain de vouloir supprimer cette \u00e9tiquette de ce fonds?",
    ":COULD_NOT_CREATE_MAPPING": "Une erreur s\u2019est produite lors de l\u2019\u00e9tiquetage du fonds.",
    ":COULD_NOT_DELETE_MAPPING": "Une erreur s\u2019est produite lors du retrait de l\u2019\u00e9tiquette du fonds.",
    ":FUND_LIST_ROLLOVER_SUMMARY": "R\u00e9partition des fonds &amp; sommaire du refinancement pour l\u2019exercice ${0}",
    ":FUND_LIST_ROLLOVER_SUMMARY_FUNDS": "<b>${1}</b> fonds accumul\u00e9s pour l\u2019exercice ${0} pour les emplacements s\u00e9lectionn\u00e9s",
    ":FUND_LIST_ROLLOVER_SUMMARY_ROLLOVER_AMOUNT": "<b>$${1}</b> les fonds non d\u00e9pens\u00e9s sont prolong\u00e9s \u00e0 l\u2019exercice ${0} pour les emplacements s\u00e9lectionn\u00e9s.",
    ":FUND_XFER_SAME_SOURCE_AND_DEST": "Transfert impossible. La provenance et la destination des fonds sont les m\u00eames.",
    ":FUND_XFER_CONFIRM": "\u00cates-vous certain d\u2019\u00eatre pr\u00eat \u00e0 proc\u00e9der \u00e0 ce transfert?",
    ":PO_ACTIVATED_ON": "Activ\u00e9(e) ${0}",
    ":PO_CHECKING": "[Un instant...]",
    ":PO_COULD_ACTIVATE": "Oui",
    ":PO_WARNING_NO_BLOCK_ACTIVATION": "Oui. Le fonds ${0} (${1}) serait consign\u00e9 au-del\u00e0 de son niveau d\u2019avertissement.",
    ":PO_STOP_BLOCKS_ACTIVATION": "Non. Les fonds ${0} (${1}) seraient consign\u00e9s au-del\u00e0 de leur niveau d\u2019arr\u00eat.",
    ":PO_ALREADY_ACTIVATED": "Activated",
    ":PO_FUND_WARNING_CONFIRM": "\u00cates-vous certain? Avez-vous vu le message d\u2019avertissement concernant la suraffectation d\u2019un fonds?",
    ":CONFIRM_FUNDS_AT_STOP": "Le solde d\u2019un ou de plusieurs des fonds s\u00e9lectionn\u00e9s est inf\u00e9rieur \u00e0 son niveau d\u2019arr\u00eat. \\nVous pourriez ne pas pouvoir activer les bons de commande qui comprennent ces exemplaires.\\nVoulez-vous continuer?",
    ":CONFIRM_FUNDS_AT_WARNING": "Le solde d\u2019un ou de plusieurs des fonds s\u00e9lectionn\u00e9s est inf\u00e9rieur \u00e0 son niveau d\u2019avertissement.\nVoulez-vous continuer?",
    ":INVOICE_ITEM_DETAILS": "${0} <br/> ${1} <br/> ${2}. <br/> Estimation du prix : $${3}. <br/> Identification de l\u2019article : ${4} <br/> Bon de commande : ${5} <br/> Date de la commande : ${6}",
    ":INVOICE_CONFIRM_ITEM_DELETE": "Supprimer ces frais $${0} '${1}' de la facture?",
    ":INVOICE_CONFIRM_ENTRY_DETACH": "Supprimer les frais $${0} pour l\u2019article '${1}, ${2} [${3}] de la facture?",
    ":LINEITEM_SUMMARY": "<div class='acq-lineitem-summary'><a href='${19}'>${0}</a>, by ${1} (${2})</div>\n<div class='acq-lineitem-summary-extra'>\n${3} Commander, ${4} Re\u00e7ues, ${7} Factur\u00e9, ${8} R\u00e9clam\u00e9, ${9} Annul\u00e9</div>\n<div class='acq-lineitem-summary-extra'>Estimation $${6}, Encombr\u00e9 $${16}, Pay\u00e9  $${17}</div>\n<div class='acq-lineitem-summary-extra'>\n# ${10} <a style='padding-right: 10px;' class='hidden${20}'  href='${11}/acq/po/view/${12}'>&#x2318; ${13} ${18}</a>\n<a style='padding-right: 10px;' class='hidden${21}' href='${11}/acq/picklist/view/${14}'>&#x2756; ${15}</a></div>",
    ":INVOICE_CONFIRM_PRORATE": "Frais calcul\u00e9s au prorata?\n\nToute modification subs\u00e9quente \u00e0 la facture qui affecterait les montants calcul\u00e9s au prorata devrait \u00eatre r\u00e9alis\u00e9e manuellement.",
    ":INVOICE_EXTRA_COPIES": "Vous tentez de facturer <b>${0}</b> un nombre d\u2019exemplaires plus \u00e9lev\u00e9 que celui command\u00e9 au d\u00e9part. <br/><br/>Pour ajouter ces articles \u00e0 la commande initiale, s\u00e9lectionner un fonds et choisir \u00ab Ajouter un nouvel article \u00bb ci-dessous. <br/>Apr\u00e8s avoir sauvegard\u00e9 la facture, vous pouvez terminer la modification et l\u2019importation de nouveaux exemplaires \u00e0 la page des d\u00e9tails de l\u2019article.",
    ":INVOICE_ITEM_PO_DETAILS": "<b>${0}</b><br/><a target='_top' href='/eg2/en-US/staff/acq/po/${2}'>PO #${3} ${4}</a><br/>Total Estimated Cost: $${5}",
    ":INVOICE_ITEM_PO_LABEL": "<a target='_top' href='/eg2/en-US/staff/acq/po/${1}'>PO #${2} ${3}</a><br/>Total Estimated Cost: $${4}",
    ":UNNAMED": "Sans nom",
    ":NO_FIND_INVOICE": "Impossible de trouver cette facture.",
    ":LI_BATCH_UPDATE": "Line item batch update",
    ":NO_LI_TO_UPDATE": "Vous n\u2019avez s\u00e9lectionn\u00e9 aucun article pour lequel une demande de r\u00e9clamation est pr\u00e9sent\u00e9e.",
    ":NO_LI_TO_CLAIM": "Vous n\u2019avez s\u00e9lectionn\u00e9 aucun article pour lequel une demande de r\u00e9clamation est pr\u00e9sent\u00e9e.",
    ":NO_LID_TO_CLAIM": "Vous n\u2019avez s\u00e9lectionn\u00e9 aucun d\u00e9tail de l\u2019article pour lequel une demande de r\u00e9clamation est pr\u00e9sent\u00e9e.",
    ":CHANGE_CLAIM_POLICY": "Modifier la politique relative aux r\u00e9clamations",
    ":CANCELED": "Annul\u00e9",
    ":RECVD": "Re\u00e7u(e)",
    ":NOT_RECVD": "Pas re\u00e7u",
    ":PRINT": "Imprim\u00e9",
    ":INVOICES": "Factures",
    ":NUM_CLAIMS_EXISTING": "R\u00e9clamations (${0} existantes)",
    ":LOAD_TERMS_FIRST": "Vous ne pouvez pas r\u00e9cup\u00e9rer les dossiers tant que vous n\u2019avez pas charg\u00e9 un fichier en format CSV comportant \ndes identifications bibliographiques dans la premi\u00e8re colonne.",
    ":SELECT_SEARCH_FIELD": "S\u00e9lectionnez le champ de recherche",
    ":LIBRARY_INITIATED": "Librairie initi\u00e9e",
    ":DEL_LI_FROM_PO": "That item has already been ordered!  Deleting it now will not revoke or modify any order that has been placed with a vendor.  Deleting the item may put the system's idea of your purchase order in a state that is inconsistent with reality.  Are you sure you mean to do this?",
    ":ADD_LI_TO_PO_BAD_PO_STATE": "The selected PO has already been activated",
    ":ADD_LI_TO_PO_BAD_LI_STATE": "The selected lineitem is not in a state that can be added to a purchase order",
    ":INVOICE_NUMBER": "Invoice #${0}",
    ":COPIES_TO_RECEIVE": "Number of copies to receive: ",
    ":CREATE_PO_INVALID": "A purchase order must have an ordering agency and a provider.",
    ":INVOICE_COPY_COUNT_INFO": "Copies received on this invoice: ${0} out of ${1}.",
    ":INVOICE_IDENT_COLLIDE": "There is already an invoice in the system with the given combination of 'Vendor Invoice ID' and 'Provider,' which is not allowed.",
    ":NEW_INVOICE": "New Invoice",
    ":ACQ_SEARCH_CLASS_ABBR_jub": "LI",
    ":ACQ_SEARCH_CLASS_ABBR_acqpl": "SL",
    ":ACQ_SEARCH_CLASS_ABBR_acqpo": "PO",
    ":ACQ_SEARCH_CLASS_ABBR_acqinv": "I",
    ":ACQ_SEARCH_CLASS_ABBR_acqlid": "LID",
    ":ACQ_SEARCH_CLASS_ABBR_acqlia": "LIA",
    ":NO_LI_GENERAL": "You have not selected any (suitable) line items.",
    ":DUPE_PO_NAME_MSG": "This name is already in use by another PO",
    ":DUPE_PO_NAME_LINK": "View PO",
    ":PO_NAME_OPTIONAL": "${0} (optional)",
    ":FINALIZE_PO": "Finalize this blanket PO?\nThis will disencumber all blanket charges and mark the PO as received",
    ":LI_EXISTING_COPIES": "There are ${0} existing copies for this bibliographic record at this location",
    ":LI_CREATING_ASSETS": "Creating bib, call number, and copy records...",
    ":PO_ACTIVATING": "Activating purchase order...",
    ":ACTIVATE_LI_PROCESSED": "Lineitems Processed: ${0}",
    ":ACTIVATE_VQBR_PROCESSED": "Vandelay Records Processed: ${0}",
    ":ACTIVATE_BIBS_PROCESSED": "Bib Records Merged/Imported: ${0}",
    ":ACTIVATE_LID_PROCESSED": "ACQ Copies Processed: ${0}",
    ":ACTIVATE_DEBITS_ACCRUED_PROCESSED": "Debits Encumbered: ${0}",
    ":ACTIVATE_COPIES_PROCESSED": "Real Copies Processed: ${0}"
}
